# roomor: A framework for autogenerating and deploying random room simulation for Gazebo

[![MIT License](https://img.shields.io/badge/license-MIT-green)](https://github.com/wwwshwww/roomor/blob/master/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/roomor)](https://pypi.org/project/roomor/)
![PyPI - Python Version](https://shields.io/pypi/pyversions/roomor)

## Installation

Install using pip:

```
$ pip install roomor
```